<?php
namespace Folha\Entities;

use HCM\Util\DateUtil;
use Importacao\Logic\Integracao\ProjetoImportacao;

class MigPessoah extends Base\MigPessoah
{

    const EXPRESSAO_NUMEROS = '/[^0-9]/';

    protected $dtvalhabcartpes;
    protected $dtinclusao;
    protected $dtpermavisto;
    protected $dtexrgpessoa;
    protected $dtnascpessoa;
    protected $dthabcartpes;
    protected $dtinscpispasep;
    protected $dtcasapessoa;
    protected $dtultatu;
    protected $dtmescompetenc;
    protected $dtcertresepes;
    protected $dsultnomepess;
    protected $dtexconsreg;
    protected $dtnaturalizapes;
    protected $dtctpspessoa;

    /**
     * @param $nrpessoah
     * @return \Folha\Entities\MigPessoah
     */
    public function setNrpessoah ($nrpessoah) {
        $nrpessoah = \Importacao\Logic\Validacoes::verificaChaveDuplicada('GPE_PESSOAH', 'NRPESSOAH', ProjetoImportacao::getNrorg(), $nrpessoah);
        $this->nrpessoah = $nrpessoah;
    }

    /**
     * @param $nrpessoa
     * @return \Folha\Entities\MigPessoah
     */
    public function setNrpessoa ($nrpessoa) {
        $nrpessoa = \Importacao\Logic\Validacoes::verificaChaveMae('GPE_PESSOA', 'NRPESSOA', ProjetoImportacao::getNrorg(), $nrpessoa);
        $this->nrpessoa = $nrpessoa;
    }

    /**
     * @param $nmpessoa
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah
     */
    public function setNmpessoa ($nmpessoa) {
        if ($nmpessoa == '' || empty($nmpessoa)) {
            $this->nmpessoa = 'NÃO CONSTA';
//            throw new \Exception("Campo Obrigatório: 'Nome'");
        } else {
            $nmpessoa = substr($nmpessoa, 0, 50);
            $this->nmpessoa = $nmpessoa;
        }
    }

//    /**
//     * @param $cdmunicipio
//     * @throws \Exception
//     * @return \Folha\Entities\MigPessoah
//     */
//    public function setCdmunicipio ($cdmunicipio) {
//        // ja é feita uma outra validação do estrutura.json
//        if (empty($cdmunicipio)) {
//            throw new \Exception("Município '$cdmunicipio' inválido ou em branco.");
//        }
//
//        $this->cdmunicipio = $cdmunicipio;
//    }

    /**
     * @param $nrracapessoa
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah
     */
    public function setNrracapessoa ($nrracapessoa) {
        $nrorg = ProjetoImportacao::getNrorgPadrao();
        $racaEntity = \Folha\Entities\GpeRacapessoa::findOneByNrracapessoaAndNrorg($nrracapessoa, $nrorg);

        if (is_object($racaEntity)) {
            $this->nrracapessoa = $nrracapessoa;
        } else {
            throw new \Exception("O código de raça '$nrracapessoa' não foi encontrado.");
        }
    }

    /**
     * @param $nrgrauinstr
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah
     */
    public function setNrgrauinstr ($nrgrauinstr) {
        try {
            if (!empty($nrgrauinstr)) {
                $nrorg = ProjetoImportacao::getNrorgPadrao();
                $grauinstEntity = \Folha\Entities\GpeGrauinstr::findOneByNrgrauinstrAndNrorg($nrgrauinstr, $nrorg);

                if (is_object($grauinstEntity)) {
                    $this->nrgrauinstr = $nrgrauinstr;
                } else {
//                    throw new \Exception("O código de Grau de Instrução '$nrgrauinstr' não foi encontrado.");
                    $this->nrgrauinstr = null;
                }
            } else {
//                throw new \Exception("O código de Grau de Instrução '$nrgrauinstr' não foi encontrado.");
                $this->nrgrauinstr = null;
            }
        } catch (\Exception $e) {
            throw new \Exception("Grau de Instrução '$nrgrauinstr' não foi encontrado.");
        }
    }

    /**
     * @param mixed $dtcasapessoa
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtcasapessoa($dtcasapessoa)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtcasapessoa)) {
            if (!empty($dtcasapessoa)) {
                throw new \Exception("Dt. Casamento: Data '$dtcasapessoa' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtcasapessoa instanceof \DateTime)) {
            $dtcasapessoa = DateUtil::getDataDeString($dtcasapessoa);
        }

        $this->dtcasapessoa = $dtcasapessoa;
    }

    /**
     * @param mixed $dtcertresepes
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtcertresepes($dtcertresepes)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtcertresepes)) {
            if (!empty($dtcertresepes)) {
                throw new \Exception("Dt. Certificado Reservista: Data '$dtcertresepes' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtcertresepes instanceof \DateTime)) {
            $dtcertresepes = DateUtil::getDataDeString($dtcertresepes);
        }

        $this->dtcertresepes = $dtcertresepes;
    }

    /**
     * @param mixed $dtctpspessoa
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtctpspessoa($dtctpspessoa)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtctpspessoa)) {
            if (!empty($dtctpspessoa)) {
                throw new \Exception("Dt. CTPS: Data '$dtctpspessoa' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtctpspessoa instanceof \DateTime)) {
            $dtctpspessoa = DateUtil::getDataDeString($dtctpspessoa);
        }

        $this->dtctpspessoa = $dtctpspessoa;
    }

    /**
     * @param mixed $dtexconsreg
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtexconsreg($dtexconsreg)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtexconsreg)) {
            if (!empty($dtexconsreg)) {
                throw new \Exception("Dt. Expedição Registro: Data '$dtexconsreg' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtexconsreg instanceof \DateTime)) {
            $dtexconsreg = DateUtil::getDataDeString($dtexconsreg);
        }

        $this->dtexconsreg = $dtexconsreg;
    }

    /**
     * @param mixed $dtexrgpessoa
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtexrgpessoa($dtexrgpessoa)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtexrgpessoa)) {
            if (!empty($dtexrgpessoa)) {
                throw new \Exception("Dt. Expedição RG: Data '$dtexrgpessoa' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtexrgpessoa instanceof \DateTime)) {
            $dtexrgpessoa = DateUtil::getDataDeString($dtexrgpessoa);
        }

        $this->dtexrgpessoa = $dtexrgpessoa;
    }

    /**
     * @param mixed $dthabcartpes
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDthabcartpes($dthabcartpes)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dthabcartpes)) {
            if (!empty($dthabcartpes)) {
                throw new \Exception("Dt. CNH: Data '$dthabcartpes' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dthabcartpes instanceof \DateTime)) {
            $dthabcartpes = DateUtil::getDataDeString($dthabcartpes);
        }

        $this->dthabcartpes = $dthabcartpes;
    }

    /**
     * @param mixed $dtinclusao
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtinclusao($dtinclusao)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinclusao)) {
            throw new \Exception("Data '$dtinclusao' com formato inválido ou em branco.");
        }

        if (!($dtinclusao instanceof \DateTime)) {
            $dtinclusao = DateUtil::getDataDeString($dtinclusao);
        }

        $this->dtinclusao = $dtinclusao;
    }

    /**
     * @param mixed $dtinscpispasep
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtinscpispasep($dtinscpispasep)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinscpispasep)) {
            if (!empty($dtinscpispasep)) {
                throw new \Exception("Dt. PIS/PASEP: Data '$dtinscpispasep' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtinscpispasep instanceof \DateTime)) {
            $dtinscpispasep = DateUtil::getDataDeString($dtinscpispasep);
        }

        $this->dtinscpispasep = $dtinscpispasep;
    }

    /**
     * @param $nrpispaseppes
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah
     */
    public function setNrpispaseppes ($nrpispaseppes) {
        if (!empty($nrpispaseppes)) {
            $pisValido = \Geral\Util\Util::validaPIS($nrpispaseppes);
            if ($pisValido) {
                $this->nrpispaseppes = $nrpispaseppes;
            } else {
                throw new \Exception("Nr. PIS/PASEP '$nrpispaseppes' inválido");
            }
        }
    }

    /**
     * @param $nrcpfpessoa
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah
     */
    public function setNrcpfpessoa ($nrcpfpessoa) {
        $nrcpfpessoa = preg_replace(self::EXPRESSAO_NUMEROS, "",$nrcpfpessoa);
        $this->nrcpfpessoa = $nrcpfpessoa;
//        if (!empty($nrcpfpessoa)) {
//            $cpfValido = \Geral\Util\Util::validaCpf($nrcpfpessoa);
//            if ($cpfValido) {
//                $this->nrcpfpessoa = $nrcpfpessoa;
//            } else {
//                throw new \Exception("CPF '$nrcpfpessoa' inválido");
//            }
//        }
    }

    /**
     * @param mixed $dtmescompetenc
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtmescompetenc($dtmescompetenc)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtmescompetenc)) {
            throw new \Exception("Campo Obrigatório -  Data de Competência: Data '$dtmescompetenc' com formato inválido ou em branco.");
        }

        if (!($dtmescompetenc instanceof \DateTime)) {
            $dtmescompetenc = DateUtil::getDataDeString($dtmescompetenc);
        }

        $this->dtmescompetenc = $dtmescompetenc;
    }

    /**
     * @param mixed $dtnascpessoa
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtnascpessoa($dtnascpessoa)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtnascpessoa)) {
            if (!empty($dtnascpessoa)) {
                throw new \Exception("Dt. Nascimento: Data '$dtnascpessoa' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtnascpessoa instanceof \DateTime)) {
            $dtnascpessoa = DateUtil::getDataDeString($dtnascpessoa);
        }

        $this->dtnascpessoa = $dtnascpessoa;
    }

    /**
     * @param mixed $dtnaturalizapes
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtnaturalizapes($dtnaturalizapes)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtnaturalizapes)) {
            if (!empty($dtnaturalizapes)) {
                throw new \Exception("Dt. Natural: Data '$dtnaturalizapes' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtnaturalizapes instanceof \DateTime)) {
            $dtnaturalizapes = DateUtil::getDataDeString($dtnaturalizapes);
        }

        $this->dtnaturalizapes = $dtnaturalizapes;
    }

    /**
     * @param mixed $dtpermavisto
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtpermavisto($dtpermavisto)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtpermavisto)) {
            if (!empty($dtpermavisto)) {
                throw new \Exception("Dt. Visto: Data '$dtpermavisto' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtpermavisto instanceof \DateTime)) {
            $dtpermavisto = DateUtil::getDataDeString($dtpermavisto);
        }

        $this->dtpermavisto = $dtpermavisto;
    }

    /**
     * @param mixed $dtultatu
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtultatu($dtultatu)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtultatu)) {
            throw new \Exception("Data '$dtultatu' com formato inválido ou em branco.");
        }

        if (!($dtultatu instanceof \DateTime)) {
            $dtultatu = DateUtil::getDataDeString($dtultatu);
        }

        $this->dtultatu = $dtultatu;
    }

    /**
     * @param mixed $dtvalhabcartpes
     * @throws \Exception
     * @return \Folha\Entities\MigPessoah|void
     */
    public function setDtvalhabcartpes($dtvalhabcartpes)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtvalhabcartpes)) {
            if (!empty($dtvalhabcartpes)) {
                throw new \Exception("Dt. Validade CNH: Data '$dtvalhabcartpes' com formato inválido ou em branco.");
            } else {
                throw new \Exception(null);
            }
        }

        if (!($dtvalhabcartpes instanceof \DateTime)) {
            $dtvalhabcartpes = DateUtil::getDataDeString($dtvalhabcartpes);
        }

        $this->dtvalhabcartpes = $dtvalhabcartpes;
    }

    /**
     * @param $cdexrgpessoa
     * @return \Folha\Entities\MigPessoah
     */
    public function setCdexrgpessoa ($cdexrgpessoa) {
        $cdexrgpessoa = substr($cdexrgpessoa, 0, 5);
        $this->cdexrgpessoa = $cdexrgpessoa;
    }

}